==> postLDAPadmin_admin-2.00.tar.gz: postldapadmin/ml/mod/mod.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * ᡼󥰥ꥹԽ
 *
 * $RCSfile: mod.php,v $
 * $Revision: 1.1.1.1 $
 * $Date: 2010/04/22 01:52:47 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibldap");
include_once("lib/dglibsess");

/***********************************************************
ƥڡ
*********************************************************/

define("OPERATION", "᡼󥰥ꥹԽ");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {

        global $result;
        global $sesskey;
        global $dispml;
        global $enc_ml;

        $newaddr = "";
        if (isset($_POST["newaddr"])) {
            $newaddr = htmlspecialchars($_POST["newaddr"]);
        }

        $dispml = htmlspecialchars($dispml);
        print <<<EOD

</script>
<form enctype="multipart/form-data" method="post" action="mod.php">
<table class="table">
  <tr>
    <td class="key1">᡼󥰥ꥹȥɥ쥹</td>
    <td class="value">$dispml</td>
    <input type="hidden" name="mladdr" value="$enc_ml">
  </tr>
  <tr>
</table>
<table>
    <td>
        <select size="10" name="addr[]" multiple>

EOD;

        if (isset($result[0]["mailForwardingAddr"])) {
            sort($result[0]["mailForwardingAddr"]);
            reset($result[0]["mailForwardingAddr"]);
            $num = 0;
            foreach($result[0]["mailForwardingAddr"] as $i) {
                $addr = $i;
                $addr = htmlspecialchars($addr);
                print("          <option value=\"$addr\">$addr" . "\n");
            }
        }

        print <<<EOD
        </select>
    </td>
    <td valign="bottom">
        <input type="submit" name="mydel" value="򤷤᡼륢ɥ쥹" onClick="return msgConfirm('򤷤᡼륢ɥ쥹ޤ\\nǤ')">
    </td>
  </tr>
</table>
<br>
<input type="text" size="40" maxlength="256" name="newaddr" value="$newaddr">
<input type="submit" name="myadd" value="ɲ">
<br><br>
<input type="file" size="40" name="filename">
<input type="submit" name="myaddlist" value="ɲ">
<input type="hidden" name="sk" value="$sesskey">
</form>
EOD;
    }
};

/*********************************************************
 * mk_addr_list
 *
 * ɥ쥹ΥꥹȤ
 *
 * []
 *           $nowlist	ߤΥꥹ
 *           $input	Ϥ줿ꥹ
 *           $list      ɥ쥹γǼ
 *           $bool      ꥹȤ˲ä(TRUE:¸ߤ| FALSE:ʤ)
 *
 * [֤]
 *	     int	ɥ쥹ο
 **********************************************************/
function mk_addr_list($nowlist, $input, &$list, $bool)
{
    global $err_msg;

    $list = array();

    $i = 0;
    /* ߤΥꥹȤĤ̵ */
    if (!is_array($nowlist)) {
        if ($bool === TRUE) {
            return 0; 
        }
        $list = $input;
        return count($list);
    }

    foreach($input as $addr) {
        reset($nowlist);
        if ((array_search($addr, $nowlist) !== FALSE) === $bool) {
            $list[] = $addr;
            $i++;
        }
    }

    return $i;
}

/***********************************************************
 * 
 **********************************************************/

/* 󥹥󥹺 */
$pg = new my_page();

/* ե롢ִեɹåå */
$ret = init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/

/* ᡼󥰥ꥹȤ򤵤Ƥʤ */
if (isset($_POST["mladdr"]) === FALSE) {

    $err_msg = "᡼󥰥ꥹȥɥ쥹ꤵƤޤ";

    result_log(OPERATION . ":NG:" . $err_msg);
    
    /* ᡼󥰥ꥹȴ̤ */
    dgp_location("index.php", $err_msg);
    exit;
}

$mladdr = $_POST["mladdr"];

/* LDAPθDN */
if (isset($_POST["myadd"]) || isset($_POST["myaddlist"]) || isset($_POST["mydel"]) ) {
    /* ̤Ǥʳʣ粽 */
    $mladdr = str_rot13($mladdr);
    $mladdr = base64_decode($mladdr);
}

$search_dn = sprintf(ADD_DN, $mladdr, $web_conf[$url_data['script']]['ldaplistsuffix'],
                     $web_conf[$url_data["script"]]["ldapbasedn"]);

$dispmlatt = $web_conf[$url_data['script']]['displayml'];

/* LDAPե륿 */
$filter = "(&(objectClass=" . PLAOC . ")" .
          "(&" . $web_conf[$url_data["script"]]["ldapmlfilter"] .
          "(" . $dispmlatt . "=*)" .
          "))";

/* Ͽ */
if (isset($_POST["myadd"])) {

    /* ɥ쥹ν񼰥å */
    if (check_mail($_POST["newaddr"]) === FALSE) {
        $err_msg = "᡼륢ɥ쥹ηޤ";
        $logstr = OPERATION . ":NG:" . $err_msg;
    } else {
        /* ᡼륢ɥ쥹μ */
        $result = array();
        $ret = main_get_entry($search_dn, $filter, array(), 
                              $web_conf[$url_data["script"]]["ldapscope"], $result);
        /* LDAP˼ */
        if ($ret != LDAP_OK) {
            $sys_err = TRUE;
            $pg->display(NULL);
            result_log(OPERATION . ":NG:" . $err_msg);
            exit (1);
        }
        $dn = $result[0]["dn"];

        /*᡼󥰥ꥹȥɥ쥹Ȥνʣå */
        if ($_POST["newaddr"] == $mladdr) {
            $err_msg = "᡼륢ɥ쥹᡼󥰥ꥹ" .
                       "ɥ쥹ȽʣƤޤ";
            $logstr = OPERATION . ":NG:" . $err_msg;
        } else {
            $attr = array("mailForwardingAddr" => $_POST["newaddr"]);

            /* °ɲ */
            $ret = LDAP_add_attribute($dn, $attr);
            if ($ret == LDAP_ERR_DUPLICATE) {
                    $err_msg = "¸ߤƤ" .
                               "᡼륢ɥ쥹ꤵƤޤ(" .
                               $_POST["newaddr"] . ")";
                    $logstr = OPERATION . ":NG:" . $err_msg;
            } elseif ($ret != LDAP_OK) {
                $logstr = OPERATION . ":NG:" . $err_msg;
            } else {
                $err_msg = "᡼륢ɥ쥹ɲäޤ({$_POST["newaddr"]})";
                $logstr = OPERATION . ":OK:" . $err_msg;
                $_POST["newaddr"] = "";
            }
        }
    }
    result_log($logstr);

/* Ͽ */
} else if (isset($_POST["myaddlist"])) {

    if (get_addr_list($_FILES["filename"]["tmp_name"], $fwaddrs) === FALSE) {
        $logstr = OPERATION . ":NG:" . $err_msg;

    } else {

        /* ᡼륢ɥ쥹μ */
        $result = array();

        $ret = main_get_entry($search_dn, $filter, array(), 
                              $web_conf[$url_data["script"]]["ldapscope"], $result);
        /* LDAP˼ */
        if ($ret != LDAP_OK) {
            $sys_err = TRUE;
            $pg->display(NULL);
            result_log(OPERATION . ":NG:" . $err_msg);
            exit (1);
        }
        $dn = $result[0]["dn"];

        if (!isset($result[0]["mailForwardingAddr"])) {
            $num = 0;
            $result[0]["mailForwardingAddr"] = array();
        }

        $num = mk_addr_list($result[0]["mailForwardingAddr"], $fwaddrs,
                                $addlist, FALSE);

        /* ᡼󥰥ꥹȥɥ쥹Ȥνʣå */
        foreach ($addlist as $eachmail) {
            if ($mladdr == $eachmail) {
                $err_msg = "᡼륢ɥ쥹᡼󥰥ꥹ" .
                           "ɥ쥹ȽʣƤޤ";
                $logstr = OPERATION . ":NG:" . $err_msg;
                $dup_flg = 1;
                break;
            }
        }

        if (!isset($dup_flg)) {
            /* °ɲ */
            if ($num != 0) {
                $attr = array("mailForwardingAddr" => $addlist);
                $ret = LDAP_add_attribute($dn, $attr);
            } else {
                $ret = LDAP_OK;
            }

            if ($ret != LDAP_OK) {
                if ($ret == LDAP_ERR_DUPLICATE) {
                    $err_msg = "¸ߤƤ᡼륢ɥ쥹ꤵƤޤ";
                }
                $logstr = OPERATION . ":NG:" . $err_msg;
            } else {
                $err_msg = "᡼륢ɥ쥹ɲäޤ";
                $logstr = OPERATION . ":OK:" . $err_msg;
            }
        }
    }
    $logstr = preg_replace("/<br>/i", " / ", $logstr);
    result_log($logstr);

/*  */
} else if (isset($_POST["mydel"])) {

    if (isset($_POST["addr"])) {

        /* ߤΥ᡼륢ɥ쥹μ */
        $result = array();
        $ret = main_get_entry($search_dn, $filter, array(), 
                              $web_conf[$url_data["script"]]["ldapscope"], $result);
        /* LDAP˼ */
        if ($ret != LDAP_OK) {
            $sys_err = TRUE;
            $pg->display(NULL);
            result_log(OPERATION . ":NG:" . $err_msg);
            exit (1);
        }
        $dn = $result[0]["dn"];

        if (!isset($result[0]["mailForwardingAddr"])) {
            $result[0]["mailForwardingAddr"] = array();
        }
        $num = mk_addr_list($result[0]["mailForwardingAddr"], $_POST["addr"],
                            $dellist, TRUE);

        /* LDAP° */
        if ($num != 0) {
            $ret = LDAP_del_attribute($dn, array("mailForwardingAddr" =>
                                                 $dellist));
        } else {
            $ret = LDAP_OK;
        }

        if ($ret != LDAP_OK) {
            if ($ret == LDAP_ERR_NOATTR) {
                $err_msg = "˺Ƥ᡼륢ɥ쥹ꤵƤޤ(dn=$dn)";
            }
            $logstr = OPERATION . ":NG:" . $err_msg;
        } else {
            $err_msg = "᡼륢ɥ쥹ޤ({$_POST["addr"][0]})";
            $logstr = OPERATION . ":OK:" . $err_msg;
        }

    } else {
        $err_msg = "᡼륢ɥ쥹򤵤Ƥޤ";
        $logstr = OPERATION . ":NG:" . $err_msg;
    }
    result_log($logstr);
}

/* ᡼륢ɥ쥹μ */
$result = array();

$ret = main_get_entry($search_dn, $filter, array(), 
                      $web_conf[$url_data["script"]]["ldapscope"], $result);
/* LDAP˼ */
if ($ret != LDAP_OK) {
    $sys_err = TRUE;
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = htmlspecialchars($err_msg);
    $pg->display(NULL);
    exit (1);
}
$dn = $result[0]["dn"];

/* ᡼󥰥ꥹȥɥ쥹Ź沽 */
$enc_ml = base64_encode($mladdr);
$enc_ml = str_rot13($enc_ml);

/* ɽѤ°Ǽ */
$dispml = $result[0]["$dispmlatt"][0];

/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display(CONTENT);

?>

==> postLDAPadmin_admin-2.20.tar.gz: postldapadmin/ml/mod/mod.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * ᡼󥰥ꥹԽ
 *
 * $RCSfile: mod.php,v $
 * $Revision: 1.2 $
 * $Date: 2010/06/10 05:23:52 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibldap");
include_once("lib/dglibsess");

/***********************************************************
ƥڡ
*********************************************************/

define("OPERATION", "᡼󥰥ꥹԽ");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {

        global $result;
        global $sesskey;
        global $dispml;
        global $enc_ml;

        $newaddr = "";
        if (isset($_POST["newaddr"])) {
            $newaddr = htmlspecialchars($_POST["newaddr"]);
        }

        $dispml = htmlspecialchars($dispml);
        print <<<EOD

</script>
<form enctype="multipart/form-data" method="post" action="mod.php">
<table class="table">
  <tr>
    <td class="key1">᡼󥰥ꥹȥɥ쥹</td>
    <td class="value">$dispml</td>
    <input type="hidden" name="mladdr" value="$enc_ml">
  </tr>
  <tr>
</table>
<table>
    <td>
        <select size="10" name="addr[]" multiple>

EOD;

        if (isset($result[0]["mailForwardingAddr"])) {
            sort($result[0]["mailForwardingAddr"]);
            reset($result[0]["mailForwardingAddr"]);
            $num = 0;
            foreach($result[0]["mailForwardingAddr"] as $i) {
                $addr = $i;
                $addr = htmlspecialchars($addr);
                print("          <option value=\"$addr\">$addr" . "\n");
            }
        }

        print <<<EOD
        </select>
    </td>
    <td valign="bottom">
        <input type="submit" name="mydel" value="" class="mail_del_btn" onClick="return msgConfirm('򤷤᡼륢ɥ쥹ޤ\\nǤ')">
    </td>
  </tr>
</table>
<br>
<input type="text" size="40" maxlength="256" name="newaddr" value="$newaddr">
<input type="submit" name="myadd" value="" class="add_btn">
<br><br>
<input type="file" size="40" name="filename">
<input type="submit" name="myaddlist" value="" class="file_add_btn">
<input type="hidden" name="sk" value="$sesskey">
</form>
EOD;
    }
};

/*********************************************************
 * mk_addr_list
 *
 * ɥ쥹ΥꥹȤ
 *
 * []
 *           $nowlist	ߤΥꥹ
 *           $input	Ϥ줿ꥹ
 *           $list      ɥ쥹γǼ
 *           $bool      ꥹȤ˲ä(TRUE:¸ߤ| FALSE:ʤ)
 *
 * [֤]
 *	     int	ɥ쥹ο
 **********************************************************/
function mk_addr_list($nowlist, $input, &$list, $bool)
{
    global $err_msg;

    $list = array();

    $i = 0;
    /* ߤΥꥹȤĤ̵ */
    if (!is_array($nowlist)) {
        if ($bool === TRUE) {
            return 0; 
        }
        $list = $input;
        return count($list);
    }

    foreach($input as $addr) {
        reset($nowlist);
        if ((array_search($addr, $nowlist) !== FALSE) === $bool) {
            $list[] = $addr;
            $i++;
        }
    }

    return $i;
}

/***********************************************************
 * 
 **********************************************************/

/* 󥹥󥹺 */
$pg = new my_page();

/* ե롢ִեɹåå */
$ret = init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/

/* ᡼󥰥ꥹȤ򤵤Ƥʤ */
if (isset($_POST["mladdr"]) === FALSE) {

    $err_msg = "᡼󥰥ꥹȥɥ쥹ꤵƤޤ";

    result_log(OPERATION . ":NG:" . $err_msg);
    
    /* ᡼󥰥ꥹȴ̤ */
    dgp_location("index.php", $err_msg);
    exit;
}

$mladdr = $_POST["mladdr"];

/* LDAPθDN */
if (isset($_POST["myadd"]) || isset($_POST["myaddlist"]) || isset($_POST["mydel"]) ) {
    /* ̤Ǥʳʣ粽 */
    $mladdr = str_rot13($mladdr);
    $mladdr = base64_decode($mladdr);
}

$search_dn = sprintf(ADD_DN, $mladdr, $web_conf[$url_data['script']]['ldaplistsuffix'],
                     $web_conf[$url_data["script"]]["ldapbasedn"]);

$dispmlatt = $web_conf[$url_data['script']]['displayml'];

/* LDAPե륿 */
$filter = "(&(objectClass=" . PLAOC . ")" .
          "(&" . $web_conf[$url_data["script"]]["ldapmlfilter"] .
          "(" . $dispmlatt . "=*)" .
          "))";

/* Ͽ */
if (isset($_POST["myadd"])) {

    /* ɥ쥹ν񼰥å */
    if (check_mail($_POST["newaddr"]) === FALSE) {
        $err_msg = "᡼륢ɥ쥹ηޤ";
        $logstr = OPERATION . ":NG:" . $err_msg;
    } else {
        /* ᡼륢ɥ쥹μ */
        $result = array();
        $ret = main_get_entry($search_dn, $filter, array(), 
                              $web_conf[$url_data["script"]]["ldapscope"], $result);
        /* LDAP˼ */
        if ($ret != LDAP_OK) {
            $sys_err = TRUE;
            $pg->display(NULL);
            result_log(OPERATION . ":NG:" . $err_msg);
            exit (1);
        }
        $dn = $result[0]["dn"];

        /*᡼󥰥ꥹȥɥ쥹Ȥνʣå */
        if ($_POST["newaddr"] == $mladdr) {
            $err_msg = "᡼륢ɥ쥹᡼󥰥ꥹ" .
                       "ɥ쥹ȽʣƤޤ";
            $logstr = OPERATION . ":NG:" . $err_msg;
        } else {
            $attr = array("mailForwardingAddr" => $_POST["newaddr"]);

            /* °ɲ */
            $ret = LDAP_add_attribute($dn, $attr);
            if ($ret == LDAP_ERR_DUPLICATE) {
                    $err_msg = "¸ߤƤ" .
                               "᡼륢ɥ쥹ꤵƤޤ(" .
                               $_POST["newaddr"] . ")";
                    $logstr = OPERATION . ":NG:" . $err_msg;
            } elseif ($ret != LDAP_OK) {
                $logstr = OPERATION . ":NG:" . $err_msg;
            } else {
                $err_msg = "᡼륢ɥ쥹ɲäޤ({$_POST["newaddr"]})";
                $logstr = OPERATION . ":OK:" . $err_msg;
                $_POST["newaddr"] = "";
            }
        }
    }
    result_log($logstr);

/* Ͽ */
} else if (isset($_POST["myaddlist"])) {

    if (get_addr_list($_FILES["filename"]["tmp_name"], $fwaddrs) === FALSE) {
        $logstr = OPERATION . ":NG:" . $err_msg;

    } else {

        /* ᡼륢ɥ쥹μ */
        $result = array();

        $ret = main_get_entry($search_dn, $filter, array(), 
                              $web_conf[$url_data["script"]]["ldapscope"], $result);
        /* LDAP˼ */
        if ($ret != LDAP_OK) {
            $sys_err = TRUE;
            $pg->display(NULL);
            result_log(OPERATION . ":NG:" . $err_msg);
            exit (1);
        }
        $dn = $result[0]["dn"];

        if (!isset($result[0]["mailForwardingAddr"])) {
            $num = 0;
            $result[0]["mailForwardingAddr"] = array();
        }

        $num = mk_addr_list($result[0]["mailForwardingAddr"], $fwaddrs,
                                $addlist, FALSE);

        /* ᡼󥰥ꥹȥɥ쥹Ȥνʣå */
        foreach ($addlist as $eachmail) {
            if ($mladdr == $eachmail) {
                $err_msg = "᡼륢ɥ쥹᡼󥰥ꥹ" .
                           "ɥ쥹ȽʣƤޤ";
                $logstr = OPERATION . ":NG:" . $err_msg;
                $dup_flg = 1;
                break;
            }
        }

        if (!isset($dup_flg)) {
            /* °ɲ */
            if ($num != 0) {
                $attr = array("mailForwardingAddr" => $addlist);
                $ret = LDAP_add_attribute($dn, $attr);
            } else {
                $ret = LDAP_OK;
            }

            if ($ret != LDAP_OK) {
                if ($ret == LDAP_ERR_DUPLICATE) {
                    $err_msg = "¸ߤƤ᡼륢ɥ쥹ꤵƤޤ";
                }
                $logstr = OPERATION . ":NG:" . $err_msg;
            } else {
                $err_msg = "᡼륢ɥ쥹ɲäޤ";
                $logstr = OPERATION . ":OK:" . $err_msg;
            }
        }
    }
    $logstr = preg_replace("/<br>/i", " / ", $logstr);
    result_log($logstr);

/*  */
} else if (isset($_POST["mydel"])) {

    if (isset($_POST["addr"])) {

        /* ߤΥ᡼륢ɥ쥹μ */
        $result = array();
        $ret = main_get_entry($search_dn, $filter, array(), 
                              $web_conf[$url_data["script"]]["ldapscope"], $result);
        /* LDAP˼ */
        if ($ret != LDAP_OK) {
            $sys_err = TRUE;
            $pg->display(NULL);
            result_log(OPERATION . ":NG:" . $err_msg);
            exit (1);
        }
        $dn = $result[0]["dn"];

        if (!isset($result[0]["mailForwardingAddr"])) {
            $result[0]["mailForwardingAddr"] = array();
        }
        $num = mk_addr_list($result[0]["mailForwardingAddr"], $_POST["addr"],
                            $dellist, TRUE);

        /* LDAP° */
        if ($num != 0) {
            $ret = LDAP_del_attribute($dn, array("mailForwardingAddr" =>
                                                 $dellist));
        } else {
            $ret = LDAP_OK;
        }

        if ($ret != LDAP_OK) {
            if ($ret == LDAP_ERR_NOATTR) {
                $err_msg = "˺Ƥ᡼륢ɥ쥹ꤵƤޤ(dn=$dn)";
            }
            $logstr = OPERATION . ":NG:" . $err_msg;
        } else {
            $err_msg = "᡼륢ɥ쥹ޤ({$_POST["addr"][0]})";
            $logstr = OPERATION . ":OK:" . $err_msg;
        }

    } else {
        $err_msg = "᡼륢ɥ쥹򤵤Ƥޤ";
        $logstr = OPERATION . ":NG:" . $err_msg;
    }
    result_log($logstr);
}

/* ᡼륢ɥ쥹μ */
$result = array();

$ret = main_get_entry($search_dn, $filter, array(), 
                      $web_conf[$url_data["script"]]["ldapscope"], $result);
/* LDAP˼ */
if ($ret != LDAP_OK) {
    $sys_err = TRUE;
    result_log(OPERATION . ":NG:" . $err_msg);
    $err_msg = htmlspecialchars($err_msg);
    $pg->display(NULL);
    exit (1);
}
$dn = $result[0]["dn"];

/* ᡼󥰥ꥹȥɥ쥹Ź沽 */
$enc_ml = base64_encode($mladdr);
$enc_ml = str_rot13($enc_ml);

/* ɽѤ°Ǽ */
$dispml = $result[0]["$dispmlatt"][0];

/***********************************************************
 * ɽ
 **********************************************************/

/* ڡν */
$pg->display(CONTENT);

?>
